@@ -1,4 +1,4 @@
-# Manual.pm 
+# Manual.pm
 # Copyright (c) 2006 Jonathan Rockway <jrockway@cpan.org>
 
 package Catalyst::Manual;
@@ -6,7 +6,10 @@ package Catalyst::Manual;
 use strict;
 use warnings;
 
-our $VERSION = '5.9009';
+our $VERSION = '5.9010';
+
+1;
+__END__
 
 =head1 NAME
 
@@ -20,9 +23,9 @@ Catalyst::Manual - The Catalyst developer's manual
 
 =head1 SEE ALSO
 
-Install L<Task::Catalyst::Tutorial|Task::Catalyst::Tutorial> to
+Install L<Task::Catalyst::Tutorial> to
 install all the dependencies you need to follow along with the
-Tutorial.  You can also refer to 
+Tutorial.  You can also refer to
 L<Catalyst::Manual::Tutorial::Intro|Catalyst::Manual::Tutorial::01_Intro>
 for more information on installation options.
 
@@ -32,7 +35,7 @@ Some "Getting Started" Links:
 
 =item *
 
-L<Catalyst::Manual::About|Catalyst::Manual::About>
+L<Catalyst::Manual::About>
 
 =item *
 
@@ -62,10 +65,6 @@ L<Catalyst::Manual::ExtendingCatalyst>
 
 L<Catalyst::Manual::Internals>
 
-=item *
-
-L<Catalyst::Manual::Plugins|Catalyst::Manual::Plugins>
-
 =back
 
 =head2 Books
@@ -76,10 +75,10 @@ For additional information on Catalyst, there are currently two books available:
 
 =item *
 
-The Definitive Guide to Catalyst: Writing Extendable, Scalable and 
+The Definitive Guide to Catalyst: Writing Extendable, Scalable and
 Maintainable Perl-Based Web Applications
 
-By: Kieren Diment, Matt Trout 
+By: Kieren Diment, Matt Trout
 Available July 12, 2009
 ISBN 10: 1-4302-2365-0
 ISBN 13: 978-1-4302-2365-8
@@ -97,15 +96,26 @@ http://www.packtpub.com/catalyst-perl-web-application/book
 
 =back
 
+=head1 SUPPORT
+
+Corrections or amendments may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Catalyst-Manual>
+(or L<bug-Catalyst-Manual@rt.cpan.org|mailto:bug-Catalyst-Manual@rt.cpan.org>).
+
+There is also a mailing list available for users of this distribution, at
+L<http://lists.scsys.co.uk/cgi-bin/mailman/listinfo/catalyst>.
+
+There is also an irc channel available for users of this distribution, at
+L<irc://irc.perl.org/#catalyst>.
+
 =head1 AUTHORS
 
-Catalyst Contributors, see Catalyst.pm
+Catalyst Contributors, see L<Catalyst>
 
-=head1 COPYRIGHT
+=head1 COPYRIGHT AND LICENCE
 
-This library is free software. You can redistribute it and/or modify it under
-the same terms as Perl itself.
+This software is copyright (c) 2006 by the Catalyst contributors.
+
+This is free software and content; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-1;
